# Changelog

## [0.0.12a46](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.12a46) (2023-07-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a45...0.0.12a46)

**Merged pull requests:**

- Loosen ovos-backend-client dependency to allow latest stable version [\#121](https://github.com/OpenVoiceOS/OVOS-workshop/pull/121) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a45](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a45) (2023-07-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a44...V0.0.12a45)

**Fixed bugs:**

- PHAL and admin PHAL failures to successfully initialize started evening of Jul 13 [\#119](https://github.com/OpenVoiceOS/OVOS-workshop/issues/119)
- fix init [\#120](https://github.com/OpenVoiceOS/OVOS-workshop/pull/120) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a44](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a44) (2023-07-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a43...V0.0.12a44)

**Merged pull requests:**

- Update OVOSAbstractApplication and unit tests [\#118](https://github.com/OpenVoiceOS/OVOS-workshop/pull/118) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a43](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a43) (2023-07-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a42...V0.0.12a43)

**Merged pull requests:**

- Fix language handling in intent and entity file resolution [\#117](https://github.com/OpenVoiceOS/OVOS-workshop/pull/117) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a42](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a42) (2023-07-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a41...V0.0.12a42)

**Closed issues:**

- Since version 0.0.12a26, settings are not reloaded with my skill [\#91](https://github.com/OpenVoiceOS/OVOS-workshop/issues/91)

**Merged pull requests:**

- Unit tests and improvements to settings change callback [\#116](https://github.com/OpenVoiceOS/OVOS-workshop/pull/116) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a41](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a41) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a40...V0.0.12a41)

## [V0.0.12a40](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a40) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a39...V0.0.12a40)

**Closed issues:**

- When core restarts, I got this trace in the "wikipedia" and "weather" skills [\#94](https://github.com/OpenVoiceOS/OVOS-workshop/issues/94)

**Merged pull requests:**

- Update `default_shutdown` with unit tests [\#115](https://github.com/OpenVoiceOS/OVOS-workshop/pull/115) ([NeonDaniel](https://github.com/NeonDaniel))
- Docstrings, Annotation, and Outlined unit tests [\#111](https://github.com/OpenVoiceOS/OVOS-workshop/pull/111) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a39](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a39) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a38...V0.0.12a39)

**Closed issues:**

- When core restarts, I got this trace in the "hello world" skill [\#93](https://github.com/OpenVoiceOS/OVOS-workshop/issues/93)

**Merged pull requests:**

- Add locking around skill settings changes [\#114](https://github.com/OpenVoiceOS/OVOS-workshop/pull/114) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a38](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a38) (2023-07-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a37...V0.0.12a38)

**Merged pull requests:**

- Update requirements.txt [\#112](https://github.com/OpenVoiceOS/OVOS-workshop/pull/112) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a37](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a37) (2023-07-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a36...V0.0.12a37)

**Merged pull requests:**

- Add docstrings and unit tests for app.py [\#110](https://github.com/OpenVoiceOS/OVOS-workshop/pull/110) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a36](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a36) (2023-07-10)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a35...V0.0.12a36)

**Implemented enhancements:**

- Skills module tests, docstrings, and annotations [\#108](https://github.com/OpenVoiceOS/OVOS-workshop/pull/108) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a35](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a35) (2023-07-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a34...V0.0.12a35)

**Merged pull requests:**

- Decorator module tests, docstrings, and annotations [\#107](https://github.com/OpenVoiceOS/OVOS-workshop/pull/107) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a34](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a34) (2023-07-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a33...V0.0.12a34)

**Merged pull requests:**

- Refactor `SkillGUI` with unit tests [\#106](https://github.com/OpenVoiceOS/OVOS-workshop/pull/106) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a33](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a33) (2023-07-04)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a32...V0.0.12a33)

**Fixed bugs:**

- fix/play\_audio [\#105](https://github.com/OpenVoiceOS/OVOS-workshop/pull/105) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a32](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a32) (2023-06-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a31...V0.0.12a32)

**Implemented enhancements:**

- feat/session\_id\_wait\_while\_speaking [\#102](https://github.com/OpenVoiceOS/OVOS-workshop/pull/102) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- handle file change errors in logs [\#100](https://github.com/OpenVoiceOS/OVOS-workshop/issues/100)

## [V0.0.12a31](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a31) (2023-06-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a30...V0.0.12a31)

**Fixed bugs:**

- fix: skill reloading broken [\#101](https://github.com/OpenVoiceOS/OVOS-workshop/pull/101) ([fidesachates](https://github.com/fidesachates))

## [V0.0.12a30](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a30) (2023-06-16)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a29...V0.0.12a30)

**Merged pull requests:**

- updated requirements [\#99](https://github.com/OpenVoiceOS/OVOS-workshop/pull/99) ([builderjer](https://github.com/builderjer))

## [V0.0.12a29](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a29) (2023-06-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a28...V0.0.12a29)

**Merged pull requests:**

- Update AudioInterface reference to resolve deprecation warning [\#98](https://github.com/OpenVoiceOS/OVOS-workshop/pull/98) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a28](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a28) (2023-06-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a27...V0.0.12a28)

**Fixed bugs:**

- fix skill initialization compat + unittests [\#95](https://github.com/OpenVoiceOS/OVOS-workshop/pull/95) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a27](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a27) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a26...V0.0.12a27)

**Merged pull requests:**

- Refactor to remove deprecated reference [\#90](https://github.com/OpenVoiceOS/OVOS-workshop/pull/90) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a26](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a26) (2023-05-17)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a25...V0.0.12a26)

**Implemented enhancements:**

- Implement Unit Tests [\#89](https://github.com/OpenVoiceOS/OVOS-workshop/pull/89) ([NeonDaniel](https://github.com/NeonDaniel))

**Closed issues:**

- When core restart, the skill returns an error [\#82](https://github.com/OpenVoiceOS/OVOS-workshop/issues/82)

## [V0.0.12a25](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a25) (2023-05-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a24...V0.0.12a25)

**Fixed bugs:**

- fix/core\_reload in standalone launcher [\#88](https://github.com/OpenVoiceOS/OVOS-workshop/pull/88) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a24](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a24) (2023-05-01)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a23...V0.0.12a24)

**Implemented enhancements:**

- refactor/skill\_init\_wizardry [\#70](https://github.com/OpenVoiceOS/OVOS-workshop/pull/70) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- fix/codecov automation [\#87](https://github.com/OpenVoiceOS/OVOS-workshop/pull/87) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a23](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a23) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a22...V0.0.12a23)

**Fixed bugs:**

- fix/missing\_requirement [\#86](https://github.com/OpenVoiceOS/OVOS-workshop/pull/86) ([JarbasAl](https://github.com/JarbasAl))

**Merged pull requests:**

- workflow/codecov [\#85](https://github.com/OpenVoiceOS/OVOS-workshop/pull/85) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a22](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a22) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a21...V0.0.12a22)

**Fixed bugs:**

- fix/activate\_plugin\_skills [\#84](https://github.com/OpenVoiceOS/OVOS-workshop/pull/84) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a21](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a21) (2023-04-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a20...V0.0.12a21)

**Fixed bugs:**

- fix/super\_fallbacks [\#83](https://github.com/OpenVoiceOS/OVOS-workshop/pull/83) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a20](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a20) (2023-04-26)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a19...V0.0.12a20)

**Fixed bugs:**

- fix/fallback\_some\_more [\#81](https://github.com/OpenVoiceOS/OVOS-workshop/pull/81) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a19](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a19) (2023-04-26)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a18...V0.0.12a19)

**Fixed bugs:**

- fix/fallback [\#80](https://github.com/OpenVoiceOS/OVOS-workshop/pull/80) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a18](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a18) (2023-04-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a17...V0.0.12a18)

**Implemented enhancements:**

- refactor/fallback\_skills\_v2 [\#66](https://github.com/OpenVoiceOS/OVOS-workshop/pull/66) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a17](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a17) (2023-04-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a16...V0.0.12a17)

## [V0.0.12a16](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a16) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a15...V0.0.12a16)

**Implemented enhancements:**

- feat/standalone\_skills [\#78](https://github.com/OpenVoiceOS/OVOS-workshop/pull/78) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a15](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a15) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a14...V0.0.12a15)

**Merged pull requests:**

- python-version: \[ 3.7, 3.8, 3.9, "3.10", "3.11"\] [\#77](https://github.com/OpenVoiceOS/OVOS-workshop/pull/77) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a14](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a14) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a13...V0.0.12a14)

**Merged pull requests:**

- refactor/common\_qa\_speak [\#63](https://github.com/OpenVoiceOS/OVOS-workshop/pull/63) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a13](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a13) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a12...V0.0.12a13)

**Fixed bugs:**

- fix/is\_classic\_core2 [\#76](https://github.com/OpenVoiceOS/OVOS-workshop/pull/76) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a12) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a11...V0.0.12a12)

**Fixed bugs:**

- fix/classic core checks [\#75](https://github.com/OpenVoiceOS/OVOS-workshop/pull/75) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a11) (2023-04-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a10...V0.0.12a11)

**Implemented enhancements:**

- feat/auto\_tx\_skills\_continued [\#74](https://github.com/OpenVoiceOS/OVOS-workshop/pull/74) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a10) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a9...V0.0.12a10)

**Fixed bugs:**

- ERROR - No module named 'ovos\_utils.lang.translate' [\#67](https://github.com/OpenVoiceOS/OVOS-workshop/issues/67)
- fix/universal\_skills\_are\_back [\#72](https://github.com/OpenVoiceOS/OVOS-workshop/pull/72) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a9) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a8...V0.0.12a9)

**Fixed bugs:**

- fix/skill\_launcher\_locale\_init [\#71](https://github.com/OpenVoiceOS/OVOS-workshop/pull/71) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a8) (2023-04-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a7...V0.0.12a8)

**Merged pull requests:**

- refactor/move\_intent\_decorators [\#73](https://github.com/OpenVoiceOS/OVOS-workshop/pull/73) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a7) (2023-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a6...V0.0.12a7)

**Implemented enhancements:**

- feat/skill\_launcher [\#65](https://github.com/OpenVoiceOS/OVOS-workshop/pull/65) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a6) (2023-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a5...V0.0.12a6)

**Merged pull requests:**

- Cleanup Changes [\#64](https://github.com/OpenVoiceOS/OVOS-workshop/pull/64) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a5) (2023-04-18)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a4...V0.0.12a5)

**Merged pull requests:**

- Update automation to match ovos-utils [\#62](https://github.com/OpenVoiceOS/OVOS-workshop/pull/62) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a4) (2023-04-14)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a3...V0.0.12a4)

**Implemented enhancements:**

- feat/common\_qa\_class [\#61](https://github.com/OpenVoiceOS/OVOS-workshop/pull/61) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a3) (2023-04-05)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a2...V0.0.12a3)

**Merged pull requests:**

- ovos-bus-client + skillGui class in ovos\_workshop [\#57](https://github.com/OpenVoiceOS/OVOS-workshop/pull/57) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.12a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a2) (2023-03-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.12a1...V0.0.12a2)

**Closed issues:**

- Add helper function `voc_list` to the OvosSkill class [\#53](https://github.com/OpenVoiceOS/OVOS-workshop/issues/53)

**Merged pull requests:**

- Add backwards-compat. voc\_cache property and setter [\#55](https://github.com/OpenVoiceOS/OVOS-workshop/pull/55) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.12a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.12a1) (2023-03-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11...V0.0.12a1)

**Merged pull requests:**

- add `voc_list` helper function [\#54](https://github.com/OpenVoiceOS/OVOS-workshop/pull/54) ([emphasize](https://github.com/emphasize))

## [V0.0.11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11) (2023-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a6...V0.0.11)

## [V0.0.11a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a6) (2023-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a5...V0.0.11a6)

**Merged pull requests:**

- Update ovos\_utils dependency to stable release [\#52](https://github.com/OpenVoiceOS/OVOS-workshop/pull/52) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.11a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a5) (2023-02-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a4...V0.0.11a5)

**Fixed bugs:**

- allow skills to bump workshop and still work in core \< 0.0.7 [\#51](https://github.com/OpenVoiceOS/OVOS-workshop/pull/51) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.11a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a4) (2023-02-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a3...V0.0.11a4)

**Merged pull requests:**

- feat/generalize runtime requirements [\#49](https://github.com/OpenVoiceOS/OVOS-workshop/pull/49) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.11a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a3) (2023-02-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a2...V0.0.11a3)

**Fixed bugs:**

- replace is\_ovos with is\_classic\_core [\#48](https://github.com/OpenVoiceOS/OVOS-workshop/pull/48) ([AIIX](https://github.com/AIIX))

## [V0.0.11a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a2) (2023-01-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.11a1...V0.0.11a2)

## [V0.0.11a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.11a1) (2023-01-28)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10...V0.0.11a1)

**Fixed bugs:**

- allow empty string value settings [\#47](https://github.com/OpenVoiceOS/OVOS-workshop/pull/47) ([emphasize](https://github.com/emphasize))

## [V0.0.10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10) (2023-01-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a6...V0.0.10)

**Merged pull requests:**

- Update ovos-core ref in unit tests [\#46](https://github.com/OpenVoiceOS/OVOS-workshop/pull/46) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.10a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a6) (2023-01-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a5...V0.0.10a6)

**Merged pull requests:**

- Update dependencies to stable versions [\#45](https://github.com/OpenVoiceOS/OVOS-workshop/pull/45) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.10a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a5) (2023-01-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a4...V0.0.10a5)

**Fixed bugs:**

- Fix message context handling in `__handle_stop` [\#44](https://github.com/OpenVoiceOS/OVOS-workshop/pull/44) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.10a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a4) (2023-01-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a3...V0.0.10a4)

**Merged pull requests:**

- Deprecate Application-managed `settings` [\#43](https://github.com/OpenVoiceOS/OVOS-workshop/pull/43) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.10a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a3) (2023-01-18)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a2...V0.0.10a3)

**Merged pull requests:**

- refactor the old patches module [\#34](https://github.com/OpenVoiceOS/OVOS-workshop/pull/34) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.10a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a2) (2023-01-17)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.10a1...V0.0.10a2)

**Implemented enhancements:**

- Get response from validated value [\#35](https://github.com/OpenVoiceOS/OVOS-workshop/pull/35) ([emphasize](https://github.com/emphasize))

## [V0.0.10a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.10a1) (2022-12-15)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.9...V0.0.10a1)

**Implemented enhancements:**

- feat/SkillNetworkRequirements [\#36](https://github.com/OpenVoiceOS/OVOS-workshop/pull/36) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.9) (2022-10-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.9a1...V0.0.9)

## [V0.0.9a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.9a1) (2022-10-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8...V0.0.9a1)

**Fixed bugs:**

- Fix circular imports [\#32](https://github.com/OpenVoiceOS/OVOS-workshop/pull/32) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a6...V0.0.8)

## [V0.0.8a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a6) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a5...V0.0.8a6)

**Merged pull requests:**

- shared code with ovos utils [\#31](https://github.com/OpenVoiceOS/OVOS-workshop/pull/31) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.8a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a5) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a4...V0.0.8a5)

## [V0.0.8a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a4) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a3...V0.0.8a4)

**Implemented enhancements:**

- feat/resource\_utils [\#30](https://github.com/OpenVoiceOS/OVOS-workshop/pull/30) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.8a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a3) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a2...V0.0.8a3)

**Implemented enhancements:**

- improve send\_stop\_signal [\#29](https://github.com/OpenVoiceOS/OVOS-workshop/pull/29) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.8a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a2) (2022-10-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.8a1...V0.0.8a2)

**Merged pull requests:**

- move OCP to optional requirements [\#28](https://github.com/OpenVoiceOS/OVOS-workshop/pull/28) ([JarbasAl](https://github.com/JarbasAl))
- license + vulnerability tests [\#27](https://github.com/OpenVoiceOS/OVOS-workshop/pull/27) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.8a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.8a1) (2022-09-13)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7...V0.0.8a1)

**Merged pull requests:**

- document results structure in ocp\_search [\#26](https://github.com/OpenVoiceOS/OVOS-workshop/pull/26) ([NeonDaniel](https://github.com/NeonDaniel))
- feat/mycroft\_integration\_tests [\#25](https://github.com/OpenVoiceOS/OVOS-workshop/pull/25) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7) (2022-07-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a12...V0.0.7)

## [V0.0.7a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a12) (2022-07-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a11...V0.0.7a12)

**Merged pull requests:**

- add initial tests for killable\_events [\#24](https://github.com/OpenVoiceOS/OVOS-workshop/pull/24) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.7a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a11) (2022-07-28)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a10...V0.0.7a11)

**Implemented enhancements:**

- feat/play\_audio [\#23](https://github.com/OpenVoiceOS/OVOS-workshop/pull/23) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.7a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a10) (2022-07-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a9...V0.0.7a10)

**Merged pull requests:**

- Update dependencies and config references [\#22](https://github.com/OpenVoiceOS/OVOS-workshop/pull/22) ([NeonDaniel](https://github.com/NeonDaniel))

## [V0.0.7a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a9) (2022-06-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a8...V0.0.7a9)

## [V0.0.7a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a8) (2022-06-02)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a7...V0.0.7a8)

**Fixed bugs:**

- Fix/decouple from mycroft [\#21](https://github.com/OpenVoiceOS/OVOS-workshop/pull/21) ([NeonJarbas](https://github.com/NeonJarbas))

## [V0.0.7a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a7) (2022-05-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a6...V0.0.7a7)

## [V0.0.7a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a6) (2022-05-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a5...V0.0.7a6)

## [V0.0.7a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a5) (2022-05-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a4...V0.0.7a5)

## [V0.0.7a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a4) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a3...V0.0.7a4)

## [V0.0.7a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a3) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a2...V0.0.7a3)

## [V0.0.7a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a2) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.7a1...V0.0.7a2)

**Merged pull requests:**

- Fix/optional adapt [\#20](https://github.com/OpenVoiceOS/OVOS-workshop/pull/20) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.7a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.7a1) (2022-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.6...V0.0.7a1)

**Fixed bugs:**

- Fix/optional adapt [\#19](https://github.com/OpenVoiceOS/OVOS-workshop/pull/19) ([JarbasAl](https://github.com/JarbasAl))

## [V0.0.6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.6) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.6a1...V0.0.6)

## [V0.0.6a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.6a1) (2022-03-03)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.5...V0.0.6a1)

**Breaking changes:**

- remove/skillgui\_patches [\#18](https://github.com/OpenVoiceOS/OVOS-workshop/pull/18) ([JarbasAl](https://github.com/JarbasAl))

**Closed issues:**

- OVOSSkill class inherited skills do not initialize [\#17](https://github.com/OpenVoiceOS/OVOS-workshop/issues/17)

## [V0.0.5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.5) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/V0.0.5a12...V0.0.5)

## [V0.0.5a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/V0.0.5a12) (2022-02-25)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/d9261b124f73a3e4d50c6edfcd9c2243b2bc3cf6...V0.0.5a12)

**Fixed bugs:**

- Fix/idleskill [\#15](https://github.com/OpenVoiceOS/OVOS-workshop/pull/15) ([NeonJarbas](https://github.com/NeonJarbas))

**Merged pull requests:**

- Feat/workflows [\#16](https://github.com/OpenVoiceOS/OVOS-workshop/pull/16) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
